#!/usr/bin/perl
#
# $Id: version.pl 340 2011-03-17 08:53:43Z gomor $
#
use strict;
use warnings;

use Net::Frame::Tools;

print "VERSION: ".$Net::Frame::Tools::VERSION."\n";
